#ifndef __VCF2MAP_H__
#define __VCF2MAP_H__

#include "StringArray.h"
#include "Pedigree.h"

#include <cassert>
#include <string>
#include <set>
#include <map>
#include <vector>
#include <algorithm>
#include <math.h>

#include <iostream>
#include "Argument.h"
#include "IO.h"
#include "tabix.h"
#include "PeopleSet.h"
#include "RangeList.h"
#include "VCFUtil.h"
#include "Error.h"

class GeneticMap
{
 public:
	std::vector<std::string> chr;
	std::vector<int> position;
	std::vector<double> distance;
	int posCounter;

 public:
	GeneticMap(){posCounter=0;}
};

class VarInfo
{
 public:
	std::string chr;
	int position;
	double EUR_AF;
	double AFR_AF;
	double ASN_AF;
	double AF;
};

class Vcf2Map
{
public:
	double minMAF;
	double minDP;
	double maxDP;
	double maxR2;
	double maxMissingRate;
	int winSize;
	int varCounter;
	int GT_idx;
	int DP_idx;
        FILE* outMap;

	std::map<std::string, int> gt2int;
	std::map<std::pair<std::string, int>, VarInfo> cleanVar;
	std::map<std::string, GeneticMap> gmap;

	std::map<std::string, int> pids;

	std::vector<VarInfo> varData;
	std::vector<std::vector<double> > geno;
	std::vector<bool> isRemoved;
	std::map<int, int> removed;
public:
	Vcf2Map();
	Vcf2Map(int winsize);
	~Vcf2Map();

	void Init();
	void Reset();
	void Reset_keepone();
	void SetWinSize(int);
	void SetMaxR2(double);
	void SetMinMAF(double);
	void SetMinAvgDP(double);
	void SetMaxAvgDP(double);
	void SetMaxMissingRate(double);
	void SetOutMapFile(FILE*);
	void LoadIncludeList(IFILE incFH);
	void LoadMapFile(IFILE mapFH);
	void GetFounders(Pedigree&);
	void ProcessVCF(std::string);
	void PruneLD();
	void GeneratePrunedMap();
	double CalcPairwiseR2(std::vector<double>& x, std::vector<double>& y);
	void PrintGenoMatrix();
};

#endif
